
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.37'
version = '1.1.37'
full_version = '1.1.37'
git_revision = '1af7841761b509c4046a960995d3a8f19dee3de9'
release = True

if not release:
    version = full_version
    short_version += ".dev"
